diff --git a/gogs.go b/gogs.go
index b66f70fdad..420bb3a6dd 100644
--- a/gogs.go
+++ b/gogs.go
@@ -4,7 +4,7 @@
 // Use of this source code is governed by a MIT-style
 // license that can be found in the LICENSE file.
 
-// Gogs(Go Git Service) is a painless self-hosted Git Service written in Go.
+// Gogs (Go Git Service) is a painless self-hosted Git Service.
 package main
 
 import (
@@ -17,7 +17,7 @@ import (
 	"github.com/gogits/gogs/modules/setting"
 )
 
-const APP_VER = "0.6.18.1031 Beta"
+const APP_VER = "0.6.19.1031 Beta"
 
 func init() {
 	runtime.GOMAXPROCS(runtime.NumCPU())
diff --git a/models/action.go b/models/action.go
index e38cf593b8..6e3587e0eb 100644
--- a/models/action.go
+++ b/models/action.go
@@ -337,6 +337,14 @@ func CommitRepoAction(
 		return fmt.Errorf("GetOwner: %v", err)
 	}
 
+	// Change repository bare status and update last updated time.
+	if repo.IsBare {
+		repo.IsBare = false
+		if err = UpdateRepository(repo, false); err != nil {
+			return fmt.Errorf("UpdateRepository: %v", err)
+		}
+	}
+
 	isNewBranch := false
 	opType := COMMIT_REPO
 	// Check it's tag push or branch.
@@ -351,12 +359,6 @@ func CommitRepoAction(
 			isNewBranch = true
 		}
 
-		// Change repository bare status and update last updated time.
-		repo.IsBare = false
-		if err = UpdateRepository(repo, false); err != nil {
-			return fmt.Errorf("UpdateRepository: %v", err)
-		}
-
 		if err = updateIssuesCommit(u, repo, repoUserName, repoName, commit.Commits); err != nil {
 			log.Error(4, "updateIssuesCommit: %v", err)
 		}
diff --git a/templates/.VERSION b/templates/.VERSION
index 9c1af4fa92..621edbbe45 100644
--- a/templates/.VERSION
+++ b/templates/.VERSION
@@ -1 +1 @@
-0.6.18.1031 Beta
\ No newline at end of file
+0.6.19.1031 Beta
\ No newline at end of file
diff --git a/routers/repo/issue.go b/routers/repo/issue.go
index 58382d18cc..fb64f6a348 100644
--- a/routers/repo/issue.go
+++ b/routers/repo/issue.go
@@ -781,8 +781,8 @@ func NewComment(ctx *middleware.Context, form auth.CreateCommentForm) {
 
 	var comment *models.Comment
 	defer func() {
-		// Check if issue owner/poster changes the status of issue.
-		if (ctx.Repo.IsOwner() || (ctx.IsSigned && issue.IsPoster(ctx.User.Id))) &&
+		// Check if issue admin/poster changes the status of issue.
+		if (ctx.Repo.IsAdmin() || (ctx.IsSigned && issue.IsPoster(ctx.User.Id))) &&
 			(form.Status == "reopen" || form.Status == "close") &&
 			!(issue.IsPull && issue.HasMerged) {
 